@@ -262,13 +262,13 @@ class S3ToLambdaProps:
         :summary: The properties for the S3ToLambda class.
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = BucketProps(**bucket_props)
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = BucketProps(**logging_bucket_props)
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(s3_event_source_props, dict):
-            s3_event_source_props = S3EventSourceProps(**s3_event_source_props)
+            s3_event_source_props = aws_cdk.aws_lambda_event_sources.S3EventSourceProps(**s3_event_source_props)
         if __debug__:
             type_hints = typing.get_type_hints(S3ToLambdaProps.__init__)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
